@@ -120,10 +120,12 @@ setMethod("determinant", signature(x = "dsCMatrix", logarithm = "logical"),
       })
 
 setMethod("writeHB", signature(obj = "dsCMatrix"),
-          function(obj, file, ...)
-          .Call(Matrix_writeHarwellBoeing,
-                if (obj@uplo == "U") t(obj) else obj,
-                as.character(file), "DSC"))
+          function(obj, file, ...) {
+              .Deprecated("writeMM")
+              .Call(Matrix_writeHarwellBoeing,
+                    if (obj@uplo == "U") t(obj) else obj,
+                    as.character(file), "DSC")
+          })
 
 setMethod("writeMM", signature(obj = "dsCMatrix"),
           function(obj, file, ...)
