@@ -9,9 +9,11 @@ SEXP Csparse_crossprod(SEXP x, SEXP trans, SEXP triplet);
 SEXP Csparse_dense_crossprod(SEXP a, SEXP b);
 SEXP Csparse_dense_prod(SEXP a, SEXP b);
 SEXP Csparse_diagU2N(SEXP x);
+SEXP Csparse_drop(SEXP x, SEXP tol);
 SEXP Csparse_horzcat(SEXP x, SEXP y);
 SEXP Csparse_submatrix(SEXP x, SEXP i, SEXP j);
 SEXP Csparse_symmetric_to_general(SEXP x);
+SEXP Csparse_general_to_symmetric(SEXP x, SEXP uplo);
 SEXP Csparse_to_Tsparse(SEXP x, SEXP tri);
 SEXP Csparse_to_dense(SEXP x);
 SEXP Csparse_to_nz_pattern(SEXP x, SEXP tri);
