@@ -40,14 +40,15 @@ static R_CallMethodDef CallEntries[] = {
     {"Csparse_dense_crossprod", (DL_FUNC) &Csparse_dense_crossprod, 2},
     {"Csparse_dense_prod", (DL_FUNC) &Csparse_dense_prod, 2},
     {"Csparse_diagU2N", (DL_FUNC) &Csparse_diagU2N, 1},
+    {"Csparse_drop", (DL_FUNC) &Csparse_drop, 2},
     {"Csparse_horzcat", (DL_FUNC) &Csparse_horzcat, 2},
     {"Csparse_to_Tsparse", (DL_FUNC) &Csparse_to_Tsparse, 2},
     {"Csparse_to_dense", (DL_FUNC) &Csparse_to_dense, 1},
     {"Csparse_to_nz_pattern", (DL_FUNC) &Csparse_to_nz_pattern, 2},
     {"Csparse_to_matrix", (DL_FUNC) &Csparse_to_matrix, 1},
     {"Csparse_submatrix", (DL_FUNC) &Csparse_submatrix, 3},
-    {"Csparse_symmetric_to_general",
-     (DL_FUNC) &Csparse_symmetric_to_general, 1},
+    {"Csparse_general_to_symmetric", (DL_FUNC)&Csparse_general_to_symmetric, 2},
+    {"Csparse_symmetric_to_general", (DL_FUNC)&Csparse_symmetric_to_general, 1},
     {"Csparse_transpose", (DL_FUNC) &Csparse_transpose, 2},
     {"Csparse_validate", (DL_FUNC) &Csparse_validate, 1},
     {"Csparse_vertcat", (DL_FUNC) &Csparse_vertcat, 2},
