@@ -2,7 +2,6 @@
 
 library(Matrix)
 
-
 h9 <- Hilbert(9)
 stopifnot(c(0,0) == dim(Hilbert(0)),
           c(9,9) == dim(h9))
@@ -21,7 +20,28 @@ options(digits=4)
 stopifnot(all.equal(as.matrix(h9),
                     as.matrix(cf9), tol= 1e-15))
 
-str(hp9 <- as(h9, "dppMatrix"))
+h9. <- round(h9, 2)
+h9.p <- as(h9., "dppMatrix")
+h4  <- h9.[1:4, 1:4] # this and the next
+h9.[1,1] <- 10       # had failed in 0.995-14
+if(FALSE) # FIXME: Error in insertMethod(methods, sig, args, def, TRUE) :...
+h9.p. <- as(h9., "dppMatrix")
+
+h9.p[1,1] <- 10 # failed in 0.995-14
+
+stopifnot(is(h9., "symmetricMatrix"),
+          is(h9.p, "symmetricMatrix"),
+          is(h4,   "symmetricMatrix"))
+
+h9.p[1,2] <- 99 #-> becomes "dgeMatrix"
+
+str(hp9 <- as(h9, "dppMatrix"))# packed
+stopifnot(is(thp9 <- t(hp9), "dppMatrix"))
+
+hs <- as(hp9, "dspMatrix")
+hs@x <- 1/hp9@x # is not pos.def. anymore
+validObject(hs)
+stopifnot(diag(hs) == seq(1, by = 2, length = 9))
 
 s9 <- solve(hp9, seq(nrow(hp9)))
 signif(t(s9)/10000, 4)# only rounded numbers are platform-independent
